package com.ruoyi.web.controller.system.check;

import cn.hutool.core.collection.CollUtil;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.system.domain.check.TdCheckReport;
import com.ruoyi.system.domain.check.dto.TdCheckReportDTO;
import com.ruoyi.system.domain.check.dto.TdCheckTypeDTO;
import com.ruoyi.system.service.check.TdCheckTypeService;
import com.ruoyi.web.controller.manager.CheckReportManager;
import com.ruoyi.web.controller.manager.SysAreaManager;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.List;
import java.util.concurrent.atomic.AtomicBoolean;

@Controller
@RequestMapping("/system/checkresult")
public class TdCheckResultController extends BaseController {
    private String prefix = "system/checkresult";

    @Resource
    private TdCheckTypeService checkTypeService;


    @Resource
    private CheckReportManager checkReportManager;

    @Resource
    private SysAreaManager sysAreaManager;

    @RequiresPermissions("system:checkresult:view")
    @GetMapping()
    public String checkresult() {
        return prefix + "/checkresult";
    }

    /**
     * 查询检查结果管理列表
     */
    @RequiresPermissions("system:checkresult:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(TdCheckReport tdCheckReport) {
        startPage();
        List<TdCheckReport> tdCheckReports = checkReportManager.selectTdCheckResultList(tdCheckReport);
        return getDataTable(tdCheckReports);
    }

    /**
     * 导出检查结果管理列表
     */
    @RequiresPermissions("system:checkresult:export")
    @Log(title = "检查结果管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ResponseBody
    public AjaxResult export(TdCheckReport tdCheckReport) {
        List<TdCheckReport> tdCheckReports = checkReportManager.selectTdCheckResultList(tdCheckReport);
        tdCheckReports.forEach(tdCheck1 -> {
            tdCheck1.setFramework(sysAreaManager.getAreaName(tdCheck1.getFramework()));
            tdCheck1.setArea(sysAreaManager.getAreaName(tdCheck1.getArea()));
        });
        ExcelUtil<TdCheckReport> util = new ExcelUtil<>(TdCheckReport.class);
        return util.exportExcel(tdCheckReports, "检查结果管理数据");
    }

    /**
     * 修改检查结果管理
     */
    @RequiresPermissions("system:checkresult:edit")
    @GetMapping("/edit/{checkId}")
    public String edit(@PathVariable("checkId") String checkId, ModelMap mmap) {
        TdCheckReportDTO tdCheckReportDTO = checkReportManager.getTdCheckReportDTO(checkId);
        mmap.put("tdCheckReportDTO", tdCheckReportDTO);
        return prefix + "/edit";
    }

    /**
     * 修改保存检查结果管理
     */
    @RequiresPermissions("system:checkresult:edit")
    @Log(title = "检查结果管理", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(@RequestBody TdCheckReportDTO checkReportDTO) {
        return toAjax(checkReportManager.saveOrUpdate(checkReportDTO));
    }

    /**
     * 删除检查结果管理
     */
    @RequiresPermissions("system:checkresult:remove")
    @Log(title = "检查结果管理", businessType = BusinessType.DELETE)
    @PostMapping("/remove")
    @ResponseBody
    public AjaxResult remove(String ids) {
        return toAjax(checkReportManager.deletedTdCheckReportIds(ids));
    }


    /**
     * 详情
     */
    @GetMapping("/view/{checkId}")
    @ResponseBody
    public AjaxResult view(@PathVariable("checkId") String checkId) {
        return AjaxResult.success(checkReportManager.getTdCheckReportDTO(checkId));
    }

    /**
     * 检查 报告管理
     */
    @RequiresPermissions("system:checkresult:check")
    @GetMapping("/checkresult/{checkId}")
    public String selfcheck(@PathVariable("checkId") String checkId, ModelMap mmap) {
        TdCheckReportDTO tdCheckReportDTO = checkReportManager.getTdCheckReportDTO(checkId);
        mmap.put("tdCheckReportDTO", tdCheckReportDTO);
        mmap.put("sysuser", getSysUser());
        return prefix + "/docheck";
    }

    /**
     * 保存检查检查结果
     */
    @RequiresPermissions("system:checkresult:check")
    @Log(title = "检查结果管理", businessType = BusinessType.CHECK)
    @PostMapping("/checkresult")
    @ResponseBody
    public AjaxResult selfcheckSave(@RequestBody TdCheckReportDTO checkReportDTO) {
        boolean flag = false;
        List<TdCheckTypeDTO> checkTypeDtoS = checkReportDTO.getCheckTypeDTOS();
        for (TdCheckTypeDTO  tdCheckTypeDTO :checkTypeDtoS){
            if("1".equals(tdCheckTypeDTO.getResultStarts())){
                flag = true;
                break;
            }
        }
        if (flag) {
            checkReportDTO.setCheckState("1");
        } else {
            checkReportDTO.setCheckState("0");
        }
        return toAjax(checkReportManager.saveOrUpdate(checkReportDTO));
    }

    /**
     * 打印操作
     */
    @RequiresPermissions("system:checkresult:print")
    @GetMapping("/checkprint/{checkId}")
    public String checkresultPrint(@PathVariable("checkId") String checkId, ModelMap mmap) {
        TdCheckReportDTO tdCheckReportDTO = checkReportManager.getTdCheckReportDTO(checkId);
        mmap.put("tdCheckReportDTO", tdCheckReportDTO);
        return prefix + "/checkresultprint";
    }

}
