package com.ruoyi.web.controller.tdcase;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.tdcase.TdCase;
import com.ruoyi.web.controller.manager.TdCaseManager;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.List;

/**
 * packageName com.ruoyi.web.controller.tdcase
 *
 * @author wangxy
 * @version JDK 8
 * @className TdCaseController
 * @date 2024/8/13
 * @description 涉密案件管理
 */
@Controller
@RequestMapping("/system/tdCase")
public class TdCaseController extends BaseController {

    private String prefix = "system/case";
    @Resource
    private TdCaseManager tdCaseManager;

    @RequiresPermissions("system:case:view")
    @GetMapping()
    public String tdCase() {
        return prefix + "/case";
    }

    /**
     * 案件列表
     */
    @RequiresPermissions("system:case:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(TdCase tdCase) {
        startPage();
        List<TdCase> tdCases = tdCaseManager.selecttdCaseList(tdCase);
        return getDataTable(tdCases);
    }


    /**
     * 新增案件
     */
    @GetMapping("/add")
    public String add() {
        return prefix + "/add";
    }

    /**
     * 新增案件
     */
    @RequiresPermissions("system:case:add")
    @Log(title = "失泄密案件", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(TdCase tdCase) {
        return toAjax(tdCaseManager.saveOrUpdate(tdCase));
    }

    /**
     * 修改案件
     */
    @RequiresPermissions("system:case:edit")
    @GetMapping("/edit/{id}")
    public String edit(@PathVariable("id") String id, ModelMap mmap) {
        TdCase tdCase = tdCaseManager.selecttdCase(id);
        mmap.put("tdCase", tdCase);
        return prefix + "/edit";
    }

    /**
     * 修改保存登记
     */
    @RequiresPermissions("system:case:edit")
    @Log(title = "失泄密案件", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(TdCase tdCase) {
        return toAjax(tdCaseManager.saveOrUpdate(tdCase));
    }

    /**
     * 案件详情
     */
    @RequiresPermissions("system:case:detail")
    @GetMapping("/detail/{id}")
    public String detail(@PathVariable("id") String id, ModelMap mmap) {
        TdCase tdCase = tdCaseManager.selecttdCase(id);
        mmap.put("tdCase", tdCase);
        return prefix + "/detail";
    }

    /**
     * 删除案件
     */
    @RequiresPermissions("system:case:remove")
    @Log(title = "失泄密案件", businessType = BusinessType.DELETE)
    @PostMapping("/remove")
    @ResponseBody
    public AjaxResult remove(String ids) {
        return toAjax(tdCaseManager.deletedCaseByids(ids));
    }

    /**
     *
     *  查询所有案件
     * @return com.ruoyi.common.core.domain.AjaxResult
     */
    @PostMapping("/getList")
    @ResponseBody
    public AjaxResult getList() {
        return AjaxResult.success(tdCaseManager.selectList());
    }


}
